rustyphoenixlecture 1.15.0

This project aims to provide a simple a powerfull lecture compilation to generate html web sites
rustyphoenixlecture-1.15.0 is not a library.

pipeline status Latest release coverage report documentation Phoenix2 documentation DOI

Code

https://gitlab.in2p3.fr/CTA-LAPP/PHOENIX_LIBS2/static-site-generator/RustyPhoenixLecture

Documentation

https://cta-lapp.pages.in2p3.fr/PHOENIX_LIBS2/static-site-generator/RustyPhoenixLecture/index.html

Requirements

  • cargo
  • rustc

Container

You can use directly a container to run rustyphoenixlecture inside a CI :

  • gitlab-registry.in2p3.fr/cta-lapp/phoenix_libs2/static-site-generator/rustyphoenixlecture/rusty_phoenix_lecture:1.14.0@sha256:ccbdd75276d5c8fda73bbadb6fba63cda2b44441c41f624c185078c9c4186c24

Installation for Users with pixi (version >=0.68!)

git clone https://gitlab.in2p3.fr/CTA-LAPP/PHOENIX_LIBS2/static-site-generator/RustyPhoenixLecture.git
cd RustyPhoenixLecture